| example_data | R Documentation |
The data set contains a binary outcome variable Y, a binary exposure A, a binary mediator M, and two confounding variables (Z1 and Z2) for 300 individuals.
example_data
example_dataA data frame with 300 rows and 5 columns:
confounders
binary exposure
binary mediator
binary outcome
...
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.